@@ -53,25 +53,21 @@ def clean_inputs(func):
 
 class StatsNbaApi:
     def __init__(self):
+        # Get a logger
         logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s: %(message)s')
         self.logger = logging.getLogger('sportsdata')
 
-        # TODO: Properly load / leverage specification file
-        api_spec_json = pkg_resources.read_text(__name__, 'data/stats.nba.com.json')
-        self.logger.info(api_spec_json)
+        # Read the specification file
+        api_spec_json = json.loads(pkg_resources.read_text('', 'stats.nba.com.json'))
+        self.specs = json.loads(api_spec_json)
 
-        # spec_json = pkg_resources.read_text(specs, 'stats.nba.com.json')
-        # print(spec_json)
-        # or for a file-like stream:
-        # template = pkg_resources.open_text(templates, 'temp_file')
-        # with open(f'{path.dirname(__file__)}/specs/stats.nba.com.json', 'r') as f:
-        #     self.specs = json.load(f)
-        #
-        # self.endpoints = {}
-        # for endpoint in self.specs['stats_endpoints']:
-        #     self.endpoints[endpoint['name']] = endpoint
+        self.logger.info(self.specs)
 
-    base_url = "http://stats.nba.com/stats/{0}"
+        self.endpoints = {}
+        for endpoint in self.specs['stats_endpoints']:
+            self.endpoints[endpoint['name']] = endpoint
+
+    base_url = "https://stats.nba.com/stats/{0}"
     headers = {
         'user-agent': (
             'Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/57.0.2987.133 Safari/537.36'),
@@ -79,7 +75,7 @@ class StatsNbaApi:
         'Dnt': ('1'),
         'Accept-Encoding': ('gzip, deflate, sdch'),
         'Accept-Language': ('en'),
-        'origin': ('http://stats.nba.com')
+        'origin': ('https://stats.nba.com')
     }
 
     ########################
